# ex-python

These examples demonstrate basic functionalities of timemory's python package features and components.

## Build

See [examples](../README.md##Build). Further, these examples require Python support `-DTIMEMORY_USE_PYTHON=ON` to be built.

## Contents

### ex-bindings
This example demonstrates the timemory support for MPI application measurements and C++ python bindings using pybind11.

### ex-general
This example demonstrates general performance measurements using timemory auto_timer, marker and profiler bundles.

### ex-profiler
This example demonstrates the timemory profiler

### ex-sample
This example demonstrate a sample application that utilizes timemory's component bundles including auto_timer and auto_tuples for performance measurement.